AWS Setup
---------

.. currentmodule:: coiled

You can use the ``coiled setup aws`` CLI tool to connect Coiled to your AWS account, which relies on your local AWS credentials::

    coiled setup aws

.. note:: No local AWS credentials?

    If you use AWS as part of a larger organization or company, you may need to contact your admin for access.
    
    For individuals, you can use `AWS CloudShell <https://aws.amazon.com/cloudshell/>`_, which already has the AWS CLI installed and configured with your AWS credentials. You can use the ``--cloudshell-link`` parameter to print instructions specific to your Coiled account::

        coiled setup aws --cloudshell-link

With your permission, this command will create the IAM policies and infrastructure Coiled needs so you can create clusters in your AWS account. You will be prompted with an explanation at each step, so you can choose to say "yes" (or "no") at any point (see :doc:`aws_configure` for more details).

Here's a demonstration of the process:

.. raw:: html
   
   <script src="https://asciinema.org/a/563412.js" id="asciicast-563412" async data-autoplay=1 data-loop=1></script>

.. click:: coiled.cli.setup.aws:aws_setup
   :prog: coiled setup aws
   :nested: none
